import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import AccountService from '@/service/account/account-service';
import EditViewEngine from '@engine/view/edit-view-engine';

/**
 * 客户编辑视图视图基类
 *
 * @export
 * @class AccountInfo_MajorContactBase
 * @extends {EditViewBase}
 */
export class AccountInfo_MajorContactBase extends EditViewBase {

    /**
     * 实体服务对象
     *
     * @type {AccountService}
     * @memberof AccountInfo_MajorContactBase
     */
    protected appEntityService: AccountService = new AccountService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof AccountInfo_MajorContactBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof AccountInfo_MajorContactBase
     */
    protected model: any = {
        srfCaption: 'entities.account.views.info_majorcontact.caption',
        srfTitle: 'entities.account.views.info_majorcontact.title',
        srfSubTitle: 'entities.account.views.info_majorcontact.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof AccountInfo_MajorContactBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'fb06f2c1cea1ac2a5a70c20f4a277ae5';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof AccountInfo_MajorContactBase
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof AccountInfo_MajorContactBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'account',
            majorPSDEField: 'accountname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof AccountInfo_MajorContactBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof AccountInfo_MajorContactBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof AccountInfo_MajorContactBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}